@@ -49,6 +49,10 @@ object.
 
 Main method to get the job done.
 
+=item logger
+
+Required coderef for logging.
+
 =back
 
 =cut
@@ -175,7 +179,7 @@ sub interpolate_indexes {
                 push @append, $add_index->($1);
             }
             if (@append) {
-                $p .= join("\n", @append);
+                $p .= "\n" . join("\n", @append);
             }
 
         }
@@ -186,7 +190,7 @@ sub interpolate_indexes {
     }
     # collect the stats
     my %stats;
-    foreach my $regex (keys %labels) {
+    foreach my $regex (sort keys %labels) {
         my $stat = $labels{$regex};
         $stats{$stat->{spec_index}} ||= 0;
         if ($stat->{matches} > 0) {
@@ -196,7 +200,7 @@ sub interpolate_indexes {
             $self->logger->("No matches found for $regex\n");
         }
     }
-    foreach my $k (keys %stats) {
+    foreach my $k (sort keys %stats) {
         $self->specifications->[$k]->total_found($stats{$k});
     }
     return join("\n\n", @out);
